==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebPaneDragActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragActionDescription } from "./WebPaneDragActionDescription";
/**
 * @hidden
 */
export let WebPaneDragActionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragActionDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragActionDescriptionMetadata.a == null) {
                WebPaneDragActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragActionDescriptionMetadata.c(WebPaneDragActionDescriptionMetadata.a);
            }
            if (a.j(WebPaneDragActionDescriptionMetadata.a)) {
                return;
            }
            a.y(WebPaneDragActionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragAction");
        }
        static d(a) {
            WebPaneDragActionDescriptionMetadata.b(a);
            a.aa("WebPaneDragAction", () => new WebPaneDragActionDescription());
            a.z("WebPaneDragAction", WebPaneDragActionDescriptionMetadata.a);
        }
    }
    WebPaneDragActionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragActionDescriptionMetadata, 'WebPaneDragActionDescriptionMetadata');
    WebPaneDragActionDescriptionMetadata.a = null;
    return WebPaneDragActionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPaneDragActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragActionDescription } from "./WebPaneDragActionDescription";
/**
 * @hidden
 */
export let WebPaneDragActionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragActionDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragActionDescriptionMetadata.a == null) {
                WebPaneDragActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragActionDescriptionMetadata.c(WebPaneDragActionDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragActionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPaneDragActionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragAction");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebPaneDragActionDescriptionMetadata.b(a);
            a.ac("WebPaneDragAction", () => new WebPaneDragActionDescription());
            a.ab("WebPaneDragAction", WebPaneDragActionDescriptionMetadata.a);
        }
    }
    WebPaneDragActionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragActionDescriptionMetadata, 'WebPaneDragActionDescriptionMetadata');
    WebPaneDragActionDescriptionMetadata.a = null;
    return WebPaneDragActionDescriptionMetadata;
})();
